kombu.exceptions — Kombu v1.3.2 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »

# kombu.exceptions

Exceptions.

copyright: | 2009 - 2011 by Ask Solem.
license: | BSD, see LICENSE for more details.

exception `kombu.exceptions.` `NotBoundError`

  Trying to call channel dependent method on unbound entity.

exception `kombu.exceptions.` `MessageStateError`

  The message has already been acknowledged.

exception `kombu.exceptions.` `TimeoutError`

  Operation timed out.

exception `kombu.exceptions.` `LimitExceeded`

  Limit exceeded.

exception `kombu.exceptions.` `ConnectionLimitExceeded`

  Maximum number of simultaneous connections exceeded.

exception `kombu.exceptions.` `ChannelLimitExceeded`

  Maximum number of simultaenous channels exceeded.

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »